@@ -4,6 +4,8 @@ from Pytheas22 import Python_Port_Scanner
 import sys
 import subprocess
 import re
+import time
+import threading
 
 
 class DysonIP:
@@ -28,9 +30,40 @@ class DysonIP:
                       str(each_number) == ip.split(".")[-1]]
         return sorted_ips
 
+    @staticmethod
+    def dyson_animation():
+        wort = "Getting the Dyson IP Address".upper()
+        while True:
+            for idx, letter in enumerate(wort):
+                try:
+                    if letter.upper() == letter:
+                        new = letter.lower()
+                    else:
+                        new = letter.upper()
+
+                    wort = Python_Port_Scanner.PortScanner.check_char(wort, idx, new)
+
+                    if "2" == letter:
+                        wort = Python_Port_Scanner.PortScanner.check_char(wort, idx, "?")
+
+                    elif "?" == letter:
+                        wort = Python_Port_Scanner.PortScanner.check_char(wort, idx, "2")
+                    Python_Port_Scanner.PortScanner.print_text(wort)
+                    time.sleep(0.1)
+                    wort = Python_Port_Scanner.PortScanner.check_char(wort, idx, letter)
+                    Python_Port_Scanner.PortScanner.print_text(wort)
+
+                    if Python_Port_Scanner.PortScanner.waiting:
+                        print()
+                        sys.exit()
+                except KeyboardInterrupt:
+                    quit()
+
     @property
     def auto_ip_addr_dyson(self):
-        bp.color("Getting IP Address.....", "green")
+        start_animation = threading.Thread(target=self.dyson_animation)
+        start_animation.start()
+
         all_ips = []
 
         if sys.platform == "linux":
@@ -46,6 +79,8 @@ class DysonIP:
             ip_lst = windows.get_every_ip()
             all_ips.extend(ip_lst)
 
+        Python_Port_Scanner.PortScanner.waiting = True
+        print()
         for ip, name in Python_Port_Scanner.PortScanner.every_ip_with_name:
             if "Dyson" in name:
                 return ip.strip()
